==> foundation-2.6.1.tgz: package/Shuffle/Shuffle.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Shuffle = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M19.401 62.222H8.022a2.536 2.536 0 00-3.013 2h-.047v11h.076a2.527 2.527 0 002.078 1.906v.094h17v-.061c1.739-.021 3.23-1.008 4.002-2.443L38.63 64.206 28.024 53.599l-8.623 8.623zm75.25-31.446l-18.614-13.26a1.255 1.255 0 00-1.319-.094 1.278 1.278 0 00-.688 1.146l.002 5.599H59.116v.026a4.577 4.577 0 00-2.781 1.138l-.021-.021L45.722 35.9l10.607 10.607 7.341-7.341h10.368l.002 6.005c0 .481.271.924.7 1.146.429.222.946.183 1.34-.099l18.576-13.346c.338-.241.461-.631.461-1.046v-.003c-.001-.417-.126-.806-.466-1.047z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.578 67.126L76.002 53.781a1.289 1.289 0 00-2.039 1.047l-.002 6.005H63.592L28.04 25.281c-.772-1.435-2.263-2.421-4.001-2.442v-.061h-17v.094a2.527 2.527 0 00-2.078 1.906h-.077v11h.049a2.535 2.535 0 003.013 2h11.378l36.913 36.913.021-.021a4.583 4.583 0 002.782 1.138v.026h14.916l-.002 5.599c0 .484.26.928.688 1.146a1.25 1.25 0 001.319-.093l18.614-13.26c.34-.242.465-.631.465-1.049v-.004c-.001-.415-.124-.806-.462-1.047z"
  }));
});
Shuffle.displayName = 'Shuffle';
export const ShuffleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Shuffle/Shuffle.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Shuffle = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M19.401 62.222H8.022a2.536 2.536 0 00-3.013 2h-.047v11h.076a2.527 2.527 0 002.078 1.906v.094h17v-.061c1.739-.021 3.23-1.008 4.002-2.443L38.63 64.206 28.024 53.599l-8.623 8.623zm75.25-31.446l-18.614-13.26a1.255 1.255 0 00-1.319-.094 1.278 1.278 0 00-.688 1.146l.002 5.599H59.116v.026a4.577 4.577 0 00-2.781 1.138l-.021-.021L45.722 35.9l10.607 10.607 7.341-7.341h10.368l.002 6.005c0 .481.271.924.7 1.146.429.222.946.183 1.34-.099l18.576-13.346c.338-.241.461-.631.461-1.046v-.003c-.001-.417-.126-.806-.466-1.047z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M94.578 67.126L76.002 53.781a1.289 1.289 0 00-2.039 1.047l-.002 6.005H63.592L28.04 25.281c-.772-1.435-2.263-2.421-4.001-2.442v-.061h-17v.094a2.527 2.527 0 00-2.078 1.906h-.077v11h.049a2.535 2.535 0 003.013 2h11.378l36.913 36.913.021-.021a4.583 4.583 0 002.782 1.138v.026h14.916l-.002 5.599c0 .484.26.928.688 1.146a1.25 1.25 0 001.319-.093l18.614-13.26c.34-.242.465-.631.465-1.049v-.004c-.001-.415-.124-.806-.462-1.047z"
  }));
});
Shuffle.displayName = 'Shuffle';
export var ShuffleDimensions = {
  height: 100,
  width: 100
};
